# Publish

## Prerequisites
* __Application server along with an SSL certificate__ binaries included for linux and windows, we're running application on CentOS 7
* __Database server__  MySQL/MariaDB, we're using MariaDB 5.5

### A course in Canvas as a guide
The start page of the app may displays information from a course within Canvas that you specify in the config file. The app displays the modules page and the items the user has permission to view. The course has to be open to all users on the specific Canvas installation.

A recommendation is that the course contains:
* Information on how to write a contract and how to define roles.
* Information on how the app works, an instruction.
* Extra material or references to extra material on group work, like group psychology and group dynamics.

A reference course is available as an IMSCC ZIP file and might be imported to your Canvas installation.

## Create configurations

### Create application config file

Use `configs/cgl.json.example` to create `cgl.json`.

Make the following adjustments:
* __oauth__: name your key (_consumer\_key_) and generate a secret (_consumer\_secret_)
* __https__: set _cert\_path_ and _key\_path_
* __canvas__: replace ... in _base\_url_, _auth\_url_ and  _token\_url_ with address to your canvas environment and in _redirect\_url_ with address to your application server
* __educational\_resources__: to display information from a course within Canvas on the start page of the app, set _id_ of the course (otherwise remove this section)

### Create LTI application definition

Use `configs/lti.xml.example` to create `configs/lti.xml`.

Make the following adjustments:
* Replace ... in URLs with address to your application server
* Set a unique _tool\_id_ (used to track app stats across accounts)

## Create database
Create database using `configs/database.sql`.

A contract template needs to be added to the database, use `configs/contract_template.sql` (and reuse script if you want to change template, application will use most recently added template).

Use `configs/database_user.sql` (replacing _username_, _host_ and _password_ in script) to create a database user for the application.

Update `cgl.json` _db.urn_ with _username_ and _password_ of created user and _address_ of database server.

## Create developer key in Canvas

Log in to Canvas using an account with administrator priviliges, navigate to _Admin_ --> your account --> _Developer keys_. Create new key by clicking  _+ Developer Key_ and choose type _API key_.
* __Key name__: name your key (users will be prompted to give key access to their account so choose a descriptive name)
* __Owner email__: your email address
* __Redirect URIs__: value from `cgl.json` _canvas.redirect\_url_
* __Enforce Scopes__: activate and choose _Read only GET_

Update `cgl.json` with _canvas.client\_id_ and _canvas.client\_secret_ from key created.

## Deploy application
Copy `canvas-group-lti` (or `canvas-group-lti.exe`), `cgl.json` and `web/static` to application server and run `canvas-group-lti` (or `canvas-group-lti.exe`).

##  Register application in Canvas

Log in to Canvas using an account with administrator priviliges and navigate to _Admin_ --> your account --> _Settings_. On the _Apps_ tab, click _View App Configurations_ and register new app by clicking _+ App_

  * __Configuration Type__: _Paste XML_
  * __Name__: Working in a group
  * __Consumer key__: value from `cgl.json` _oauth.consumer\_key_
  * __Shared secret__: value from `cgl.json` _oauth.consumer\_secret_
  * __XML configuration__: paste `configs/lti.xml`.

An instructor can now add application to course navigation (under _Settings_ --> _Navigation_).