package canvas

import (
	"encoding/json"
	"fmt"
	"log"
)

// GroupCategory represents a Canvas group category
// https://canvas.instructure.com/doc/api/group_categories.html
type GroupCategory struct {
	ID   int
	Name string
}

// GroupCategories returns the group categories for a given course
// https://canvas.instructure.com/doc/api/group_categories.html#method.group_categories.index
func (c Client) GroupCategories(ID CourseID) ([]GroupCategory, error) {
	gcs := []GroupCategory{}

	url := fmt.Sprintf("%s/courses/%v/group_categories", c.baseurl, ID)
	log.Printf("Canvas.CourseGroups: %v", url)
	resp, err := c.client.Get(url)
	if err != nil {
		return gcs, err
	}
	defer resp.Body.Close()

	if resp.StatusCode < 200 || resp.StatusCode > 299 {
		return gcs, fmt.Errorf("Canvas.GroupCategory: Canvas said %v", resp.Status)
	}

	if err := json.NewDecoder(resp.Body).Decode(&gcs); err != nil {
		return gcs, fmt.Errorf("Canvas.GroupCategory: %v", err)
	}

	return gcs, nil
}
