package canvas

import (
	"encoding/json"
	"fmt"
	"log"
)

// User represents a Canvas user
// https://canvas.instructure.com/doc/api/users.html#User
type User struct {
	ID   int    `json:"id"`
	Name string `json:"name"`
}

// UserByID returns a specific user
// https://canvas.instructure.com/doc/api/users.html#method.users.api_show
func (c Client) UserByID(userID int) (User, error) {
	user := User{}

	url := fmt.Sprintf("%s/users/%d", c.baseurl, userID)
	log.Printf("Canvas.UserById: %v", url)
	resp, err := c.client.Get(url)
	if err != nil {
		return user, err
	}
	defer resp.Body.Close()

	if resp.StatusCode < 200 || resp.StatusCode > 299 {
		return user, fmt.Errorf("Canvas.UserById: Canvas said %v", resp.Status)
	}

	if err := json.NewDecoder(resp.Body).Decode(&user); err != nil {
		return user, fmt.Errorf("Canvas.UserById: %v", err)
	}

	return user, nil
}
