package session

import (
	"sync"
	"time"
)

// MemorySessionStore represents a memory backed session store
type MemorySessionStore struct {
	sync.Mutex
	sessions map[string]*MemorySession
}

// MemorySession represents a single session
type MemorySession struct {
	sync.Mutex
	expires time.Time
	values  map[string]string
}

// NewMemorySessionStore returns a new memory based session store
func NewMemorySessionStore() *MemorySessionStore {
	return &MemorySessionStore{
		sessions: make(map[string]*MemorySession),
	}
}

// Session returns the given session or a new empty session
func (ms *MemorySessionStore) Session(sessionID string) *MemorySession {
	ms.Lock()
	defer ms.Unlock()
	var s *MemorySession
	s, ok := ms.sessions[sessionID]
	if !ok {
		s = &MemorySession{
			values: make(map[string]string),
		}
		ms.sessions[sessionID] = s
	}
	return s
}

// Get gets a value
func (ms *MemorySession) Get(key string) string {
	ms.Lock()
	defer ms.Unlock()
	return ms.values[key]
}

// Set sets a value
func (ms *MemorySession) Set(key, val string) {
	ms.Lock()
	defer ms.Unlock()
	ms.values[key] = val
}
