import { BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { NgModule } from '@angular/core';
import { APP_BASE_HREF } from '@angular/common';
import { HttpClientModule, HTTP_INTERCEPTORS } from '@angular/common/http';
import { FormsModule } from '@angular/forms';

import { NgbCollapseModule, NgbTabsetModule, NgbRatingModule, NgbModalModule, NgbTooltipModule } from '@ng-bootstrap/ng-bootstrap';
import { QuillModule } from 'ngx-quill';

import { AppRoutingModule } from './app-routing.module';
import { AppComponent } from './app.component';
import { SelectGroupComponent } from './select-group/select-group.component';
import { ContractComponent } from './contract/contract.component';
import { RolesComponent } from './roles/roles.component';
import { RoleDefinitionsComponent } from './role-definitions/role-definitions.component';
import { ApprovalComponent } from './approval/approval.component';
import { BehaviorSubject } from 'rxjs';
import { MessagesComponent } from './messages/messages.component';
import { EducationComponent } from './education/education.component';
import { SaveChangesModalComponent } from './save-changes-modal/save-changes-modal.component';
import { ConfirmDeleteModalComponent } from './confirm-delete-modal/confirm-delete-modal.component';
import { GroupStatusComponent } from './group-status/group-status.component'

import { BusyInterceptor } from './shared/interceptors/busy.interceptor'

@NgModule({
  declarations: [
    AppComponent,
    SelectGroupComponent,
    ContractComponent,
    RolesComponent,
    RoleDefinitionsComponent,
    ApprovalComponent,
    MessagesComponent,
    EducationComponent,
    SaveChangesModalComponent,
    ConfirmDeleteModalComponent,
    GroupStatusComponent
  ],
  imports: [
    BrowserModule,
    BrowserAnimationsModule,
    AppRoutingModule,
    HttpClientModule,
    FormsModule,
    NgbCollapseModule,
    NgbRatingModule,
    NgbTabsetModule,
    NgbTooltipModule,
    NgbModalModule,
    QuillModule.forRoot({
      modules: {
        toolbar: [
          ['bold', 'italic', 'underline', 'strike'],
          [{ 'list': 'ordered'}, { 'list': 'bullet' }],
          [{ 'header': [1, 2, 3, 4, 5, 6, false] }],
          [{ 'font': [] }],
          [{ 'align': [] }]
        ]
      }
    })
  ],
  providers: [
    { provide: APP_BASE_HREF, useValue: '/' },  // TODO: get value from environment
    { provide: 'CGLSessionToken', useValue: new BehaviorSubject('') },
    { provide: HTTP_INTERCEPTORS, useClass: BusyInterceptor, multi: true }
  ],
  bootstrap: [AppComponent]
})
export class AppModule { }
