import { Component, Input, SimpleChanges, SimpleChange, OnChanges, OnInit } from '@angular/core';
import { forkJoin } from 'rxjs';

import { Contract } from '../shared/models/contract';
import { GroupService } from '../shared/services/group.service';
import { Group } from '../shared/models/group';


enum ContractStates {
  CLEAN = 1,
  DIRTY,
  SAVING,
  LOADING
}

@Component({
  selector: 'app-contract',
  templateUrl: './contract.component.html',
  styleUrls: ['./contract.component.css']
})
export class ContractComponent implements OnInit, OnChanges {

  @Input() readonly: boolean;
  @Input() disabled: boolean;
  @Input() group: Group;

  contract: Contract;
  standardContract: Contract;
  contractStates = ContractStates;
  contractState = ContractStates.CLEAN;
  statusText: string;

  constructor(private groupService: GroupService) { }

  ngOnInit() {
    this.contractState = this.contractStates.CLEAN;
  }

  ngOnChanges(changes: SimpleChanges) {
    if (changes.group) {
      const groupChange: SimpleChange = changes.group;
      this.setGroup(groupChange.currentValue);
    }
  }

  setGroup(group: Group) {
    this.group = group;

    // reload contract
    this.contract = null;
    this.loadData();
  }

  setState(state: ContractStates) {
    switch (state) {
      case ContractStates.SAVING:
        this.statusText = "Saving contract...";
        break;
      case ContractStates.LOADING:
        this.statusText = "Loading contract...";
        break;
      default:
        this.statusText = "";
        break;
    }
    this.contractState = state;
  }

  loadData(): void {
    if (this.group) {
      this.setState(ContractStates.LOADING);
      forkJoin(this.groupService.getStandardContract(), this.groupService.getContract(this.group.id))
        .subscribe(result => {
          this.standardContract = result[0];

          if (result[1]) {
            this.contract = result[1];
          } else {
            this.contract = new Contract();
            this.contract.body = this.standardContract.body;
          }
          this.setState(ContractStates.CLEAN);
        });
    }
  }

  saveContract(): void {
    if (!this.group) {
      return;
    }

    this.setState(ContractStates.SAVING);
    this.groupService.updateContract(this.group.id, this.contract)
      .subscribe(
        result => this.setState(ContractStates.CLEAN),
        error => this.setState(ContractStates.DIRTY)
      );
  }

  isDirty(): boolean {
    return this.contractState === ContractStates.DIRTY;
  }
}
