import { Component, OnInit, Input, Output, EventEmitter } from '@angular/core';

import { Group } from '../shared/models/group';
import { GroupService } from '../shared/services/group.service'

@Component({
  selector: 'app-select-group',
  templateUrl: './select-group.component.html',
  styleUrls: ['./select-group.component.css']
})
export class SelectGroupComponent implements OnInit {

  groups: Group [];
  selectedGroup: Group;

  @Input() disabled: boolean;

  @Output() selectedGroupChanged: EventEmitter<Group> = new EventEmitter<Group>();

  constructor(private groupService: GroupService) { }

  ngOnInit() {
    this.getGroups();
  }

  getGroups(): void {
    this.groupService.getGroups()
      .subscribe(result => {
        this.groups = result;
        this.setDefaultSelectedGroup();
      });
  }

  setDefaultSelectedGroup(): void {

    // when there is only one group this group shall be selected by default
    if (this.groups != null && this.groups.length === 1) {
      this.selectedGroup = this.groups[0];
    }

    // otherwise no group shall be selected
    else {
      this.selectedGroup = null;
    }

    this.notifySubscribers();
  }

  notifySubscribers(): void {
    this.selectedGroupChanged.emit(this.selectedGroup);
  }
}
