import { Injectable } from '@angular/core';
import { interval } from 'rxjs';
import { Message, MessageTypes } from '../models/message';

@Injectable({
  providedIn: 'root'
})
export class MessageService {

  messages: Message [] = [];

  constructor() {
    interval(2500)
      .subscribe(() => this.purgeOldMessages());
   }

  addInfo(text: string) {
    let message = this.createMessage(text);
    message.messageType = MessageTypes.Info;

    this.messages.push(message);
  }


  addWarning(text: string) {
    let message = this.createMessage(text);
    message.messageType = MessageTypes.Warn;

    this.messages.push(message);
  }

  addError(text: string) {
    let message = this.createMessage(`An error occured: ${text}`);
    message.messageType = MessageTypes.Error;

    this.messages.push(message);
  }

  removeMessage(message: Message) {
    this.messages.forEach( (item, index) => {
      if(item.id === message.id) this.messages.splice(index,1);
    });
  }

  private createMessage(text: string): Message {
    var message = new Message();
    message.id = this.messages.length > 0 ? Math.max(...this.messages.map(message => message.id)) + 1 : 1;
    message.creationTime = Date.now();
    message.text = text;

    return message;
  }

  private purgeOldMessages() {
    var now = Date.now();
    var stillSearching: boolean = true; // only remove one item per call
    this.messages.forEach( (item, index) => {
      if (stillSearching && now - item.creationTime >= 5000) {
        this.messages.splice(index,1);
        stillSearching = false;
      }
    });
  }

}
